@@ -25,7 +25,6 @@
  *
  */
 
-const DBus = imports.dbus;
 const Lang = imports.lang;
 
 // util imports
@@ -39,64 +38,37 @@ const Gio = imports.gi.Gio;
 
 const MainWindow = imports.ui.mainWindow;
 
-const _SUSHI_DBUS_PATH = '/org/gnome/NautilusPreviewer';
+const SUSHI_DBUS_PATH = '/org/gnome/NautilusPreviewer';
+const SUSHI_DBUS_NAME = 'org.gnome.NautilusPreviewer';
 
-const SushiIface = {
-    name: 'org.gnome.NautilusPreviewer',
+const SushiIface = <interface name={SUSHI_DBUS_NAME}>
+<method name="ShowFile">
+    <arg type="s" direction="in" name="uri" />
+    <arg type="i" direction="in" name="xid" />
+    <arg type="b" direction="in" name="closeIfAlreadyShown" />
+</method>
+<method name="Close">
+</method>
+</interface>;
 
-    methods: [ { name: 'Activate',
-                 inSignature: '',
-                 outSignature: '' },
-               { name: 'ShowFile',
-                 inSignature: 'sib',
-                 outSignature: '' },
-               { name: 'Close',
-                 inSignature: '',
-                 outSignature: '' }],
+const Application = new Lang.Class({
+    Name: 'Application',
+    Extends: Gtk.Application,
 
-    signals: [],
-    properties: []
-};
-
-function RemoteApplication(args) {
-    this._init(args);
-}
-
-RemoteApplication.prototype = {
     _init : function(args) {
-        DBus.session.proxifyObject(this,
-                                   SushiIface.name,
-                                   _SUSHI_DBUS_PATH);
-    }
-}
-
-DBus.proxifyPrototype(RemoteApplication.prototype,
-                      SushiIface);
-
-function Application(args) {
-    this._init(args);
-}
-
-Application.prototype = {
-    _init : function(args) {
-        DBus.session.acquire_name(SushiIface.name,
-                                  DBus.SINGLE_INSTANCE,
-                                  Lang.bind(this, this._onNameAcquired),
-                                  Lang.bind(this, this._onNameNotAcquired));
+        this.parent({ application_id: SUSHI_DBUS_NAME });
     },
 
-    _onNameAcquired : function() {
-        DBus.session.exportObject(_SUSHI_DBUS_PATH, this);
+    vfunc_startup : function() {
+        this.parent();
+        this._dbusImpl = Gio.DBusExportedObject.wrapJSObject(SushiIface, this);
+        this._dbusImpl.export(Gio.DBus.session, SUSHI_DBUS_PATH);
 
         this._defineStyleAndThemes();
         this._createMainWindow();
     },
 
-    _onNameNotAcquired : function() {
-        let remoteApp = new RemoteApplication();
-        remoteApp.ActivateRemote();
-
-        this.quit();
+    vfunc_activate : function() {
     },
 
     _createMainWindow : function() {
@@ -115,11 +87,8 @@ Application.prototype = {
         settings.gtk_application_prefer_dark_theme = true;
     },
 
-    Activate : function() {
-    },
-
     Close: function() {
-        this.quit();
+        this._mainWindow.close();
     },
 
     ShowFile : function(uri, xid, closeIfAlreadyShown) {
@@ -132,9 +101,5 @@ Application.prototype = {
 	}
         this._mainWindow.setParent(xid);
         this._mainWindow.setFile(file);
-    },
-
-    quit : function() {
-        Gtk.main_quit();
     }
-}
+});
